@@ -7,7 +7,8 @@ from .models import FaqPluginModel, Keyword, QuestionFaqPluginModel
 
 
 class DjangocmsFaqFaqPluginModel(PlaceholderAdminMixin, admin.ModelAdmin):
-    list_display = ("name", "language", "get_page_url", "id")
+    list_display = ("name", "language", "get_page_url", "uuid")
+    readonly_fields = ["uuid"]
 
     def get_queryset(self, request):
         qs = (
