@@ -4,10 +4,12 @@ from django.http import HttpResponse
 
 from djangocms_faq.utils import get_answers
 
+from .settings import MAX_QUERY_LENGTH
+
 
 def AnswerView(request):
-    if "question" in request.GET:
-        question = request.GET["question"]
+    if "question" in request.GET and len(request.GET["question"]) > 2:
+        question = request.GET["question"][:MAX_QUERY_LENGTH]
 
         if "search_in" in request.GET:
             search_in = request.GET["search_in"]
